@@ -2,9 +2,6 @@
  * vncfunc.c: VNC Client functions to be used for the graphical VNC console of libvirt-php
  *
  * See COPYING for the license of this software
- *
- * Written by:
- *   Michal Novotny <minovotn@redhat.com>
  */
 
 #include <config.h>
@@ -26,7 +23,7 @@
 DEBUG_INIT("vncfunc");
 
 /* Function macro */
-#define PHPFUNC __FUNCTION__
+#define VNCFUNC __FUNCTION__
 
 #define UC(a) (unsigned char)a
 #define CALC_UINT32(a, b, c, d) (uint32_t)((a >> 24) + (b >> 16) + (c >> 8) + d)
@@ -96,11 +93,11 @@ vnc_write_client_version(int sfd)
     if (write(sfd, buf, 12) < 0) {
         int err = errno;
         close(sfd);
-        DPRINTF("%s: Write of client version failed\n", PHPFUNC);
+        DPRINTF("%s: Write of client version failed\n", VNCFUNC);
         return -err;
     }
 
-    DPRINTF("%s: VNC Client version packet sent\n", PHPFUNC);
+    DPRINTF("%s: VNC Client version packet sent\n", VNCFUNC);
     return 0;
 }
 
@@ -124,7 +121,7 @@ vnc_authorize(int sfd)
     /* Read number security types supported */
     if ((num = read(sfd, buf, 1)) < 0) {
         int err = errno;
-        DPRINTF("%s: Cannot read number of security types, error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: Cannot read number of security types, error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
@@ -132,7 +129,7 @@ vnc_authorize(int sfd)
     /* Read all the security types */
     if (read(sfd, buf2, num) < 0) {
         int err = errno;
-        DPRINTF("%s: Read function failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: Read function failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
@@ -147,7 +144,7 @@ vnc_authorize(int sfd)
     /* Bail if security type None is not supported */
     if (ok == 0) {
         close(sfd);
-        DPRINTF("%s: Security type None is not supported\n", PHPFUNC);
+        DPRINTF("%s: Security type None is not supported\n", VNCFUNC);
         return -ENOTSUP;
     }
 
@@ -159,7 +156,7 @@ vnc_authorize(int sfd)
         return -err;
     }
 
-    DPRINTF("%s: Security None selected\n", PHPFUNC);
+    DPRINTF("%s: Security None selected\n", VNCFUNC);
 
     /* Just bogus to wait for proper auth response */
     i = 0;
@@ -167,7 +164,7 @@ vnc_authorize(int sfd)
     while (buf[0] + buf[1] + buf[2] + buf[3] != 0) {
         if (read(sfd, buf, 4) < 0) {
             int err = errno;
-            DPRINTF("%s: Read function failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+            DPRINTF("%s: Read function failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
             close(sfd);
             return -err;
         }
@@ -177,7 +174,7 @@ vnc_authorize(int sfd)
         }
     }
 
-    DPRINTF("%s: VNC Client authorized\n", PHPFUNC);
+    DPRINTF("%s: VNC Client authorized\n", VNCFUNC);
     return 0;
 }
 
@@ -203,13 +200,13 @@ vnc_parse_fb_params(unsigned char *buf, int len)
 
     little_endian = (buf[6] == 0);
 
-    DPRINTF("%s: Read dimension bytes: width = { 0x%02x, 0x%02x }, height = { 0x%02x, 0x%02x }, %s endian\n", PHPFUNC,
+    DPRINTF("%s: Read dimension bytes: width = { 0x%02x, 0x%02x }, height = { 0x%02x, 0x%02x }, %s endian\n", VNCFUNC,
             w1, w2, h1, h2, little_endian ? "little" : "big");
 
     w = SWAP2_BY_ENDIAN(little_endian, w1, w2);
     h = SWAP2_BY_ENDIAN(little_endian, h1, h2);
 
-    DPRINTF("%s: Filling the parameters structure with width = %d, height = %d\n", PHPFUNC, w, h);
+    DPRINTF("%s: Filling the parameters structure with width = %d, height = %d\n", VNCFUNC, w, h);
 
     params.width = w;
     params.height = h;
@@ -232,14 +229,14 @@ vnc_parse_fb_params(unsigned char *buf, int len)
     params.desktopNameLen = nlen;
     params.desktopName =  (unsigned char*) strdup((char *)buf + 24);
 
-    DPRINTF("%s: Desktop name set to '%s'\n", PHPFUNC, params.desktopName);
+    DPRINTF("%s: Desktop name set to '%s'\n", VNCFUNC, params.desktopName);
 
     DPRINTF("%s: width = %d, height = %d, bpp = %d, depth = %d, bigEndian = %d, trueColor = %d\n",
-            PHPFUNC, params.width, params.height, params.bpp, params.depth, params.bigEndian, params.trueColor);
-    DPRINTF("%s: maxColors = { %d, %d, %d }, shifts = { %d, %d, %d }\n", PHPFUNC, params.maxRed,
+            VNCFUNC, params.width, params.height, params.bpp, params.depth, params.bigEndian, params.trueColor);
+    DPRINTF("%s: maxColors = { %d, %d, %d }, shifts = { %d, %d, %d }\n", VNCFUNC, params.maxRed,
             params.maxGreen, params.maxBlue, params.shiftRed, params.shiftGreen, params.shiftBlue);
 
-    DPRINTF("%s: Desktop name is '%s' (%d bytes)\n", PHPFUNC, params.desktopName, params.desktopNameLen);
+    DPRINTF("%s: Desktop name is '%s' (%d bytes)\n", VNCFUNC, params.desktopName, params.desktopNameLen);
 
     return params;
 }
@@ -269,18 +266,18 @@ vnc_send_key(int sfd, unsigned char key, int modifier, int release)
     buf[6] = modifier ? 0xff : 0x00;
     buf[7] = key;
 
-    DPRINTF("%s: %s key %d [0x%02x], modifier: %s\n", PHPFUNC, (release ? "Releasing" : "Pressing"),
+    DPRINTF("%s: %s key %d [0x%02x], modifier: %s\n", VNCFUNC, (release ? "Releasing" : "Pressing"),
             key, key, modifier ? "true" : "false");
 
     if (write(sfd, buf, 8) < 0) {
         int err = errno;
         DPRINTF("%s: Error occured while writing to socket descriptor #%d: %d (%s)\n",
-                PHPFUNC, sfd, err, strerror(err));
+                VNCFUNC, sfd, err, strerror(err));
         close(sfd);
         return -err;
     }
 
-    DPRINTF("%s: Write of 8 bytes successful\n", PHPFUNC);
+    DPRINTF("%s: Write of 8 bytes successful\n", VNCFUNC);
 
     return 0;
 }
@@ -301,7 +298,7 @@ vnc_send_client_pointer(int sfd, int clicked, int pos_x, int pos_y)
     unsigned char buf[6] = { 0 };
 
     if (sfd < 0) {
-        DPRINTF("%s: Socket is not opened!\n", PHPFUNC);
+        DPRINTF("%s: Socket is not opened!\n", VNCFUNC);
         return -EINVAL;
     }
 
@@ -314,14 +311,14 @@ vnc_send_client_pointer(int sfd, int clicked, int pos_x, int pos_y)
 
     if (write(sfd, buf, 6) < 0) {
         int err = errno;
-        DPRINTF("%s: Write function failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: Write function failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
 
 
     DPRINTF("%s: Wrote 6 bytes of client pointer event, clicked = %d, x = { 0x%02x, 0x%02x }, y = { 0x%02x, 0x%02x }\n",
-            PHPFUNC, buf[1], buf[2], buf[3], buf[4], buf[5]);
+            VNCFUNC, buf[1], buf[2], buf[3], buf[4], buf[5]);
     return 0;
 }
 
@@ -339,11 +336,11 @@ vnc_set_pixel_format(int sfd, tServerFBParams params)
     unsigned char buf[20];
 
     if (sfd < 0) {
-        DPRINTF("%s: Socket is not opened!\n", PHPFUNC);
+        DPRINTF("%s: Socket is not opened!\n", VNCFUNC);
         return -EINVAL;
     }
 
-    DPRINTF("%s: Setting up pixel format\n", PHPFUNC);
+    DPRINTF("%s: Setting up pixel format\n", VNCFUNC);
 
     memset(buf, 0, 20);
     /* Message type 0 is SetPixelFormat message */
@@ -373,12 +370,12 @@ vnc_set_pixel_format(int sfd, tServerFBParams params)
 
     if (write(sfd, buf, 20) < 0) {
         int err = errno;
-        DPRINTF("%s: Write function failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: Write function failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
 
-    DPRINTF("%s: Pixel format set\n", PHPFUNC);
+    DPRINTF("%s: Pixel format set\n", VNCFUNC);
 
     return 0;
 }
@@ -396,11 +393,11 @@ vnc_set_encoding(int sfd)
     unsigned char buf[8];
 
     if (sfd < 0) {
-        DPRINTF("%s: Socket is not opened!\n", PHPFUNC);
+        DPRINTF("%s: Socket is not opened!\n", VNCFUNC);
         return -EINVAL;
     }
 
-    DPRINTF("%s: Setting up encoding\n", PHPFUNC);
+    DPRINTF("%s: Setting up encoding\n", VNCFUNC);
 
     memset(buf, 0, 8);
     buf[0] = 0x02;
@@ -415,12 +412,12 @@ vnc_set_encoding(int sfd)
 
     if (write(sfd, buf, 8) < 0) {
         int err = errno;
-        DPRINTF("%s: Write function failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: Write function failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
 
-    DPRINTF("%s: Client encoding set\n", PHPFUNC);
+    DPRINTF("%s: Client encoding set\n", VNCFUNC);
     return 0;
 }
 
@@ -442,11 +439,11 @@ vnc_send_framebuffer_update(int sfd, int incrementalUpdate, int x, int y, int w,
     unsigned char buf[10];
 
     if (sfd < 0) {
-        DPRINTF("%s: Socket is not opened!\n", PHPFUNC);
+        DPRINTF("%s: Socket is not opened!\n", VNCFUNC);
         return -EINVAL;
     }
 
-    DPRINTF("%s: Sending %s update request\n", PHPFUNC, (incrementalUpdate ? "standard" : "incremental"));
+    DPRINTF("%s: Sending %s update request\n", VNCFUNC, (incrementalUpdate ? "standard" : "incremental"));
     memset(buf, 0, 10);
     buf[0] = 0x03;
     buf[1] = incrementalUpdate;
@@ -458,12 +455,12 @@ vnc_send_framebuffer_update(int sfd, int incrementalUpdate, int x, int y, int w,
 
     if (write(sfd, buf, 10) < 0) {
         int err = errno;
-        DPRINTF("%s: Write function failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: Write function failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
 
-    DPRINTF("%s: Request sent\n", PHPFUNC);
+    DPRINTF("%s: Request sent\n", VNCFUNC);
 
     return 0;
 }
@@ -502,11 +499,11 @@ vnc_connect(char *server, char *port, int share)
     if (sfd < 0)
         return sfd;
 
-    DPRINTF("%s: Opened socket with descriptor #%d\n", PHPFUNC, sfd);
+    DPRINTF("%s: Opened socket with descriptor #%d\n", VNCFUNC, sfd);
 
     if (read(sfd, buf, 1024) < 0) {
         int err = errno;
-        DPRINTF("%s: Read function failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: Read function failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
@@ -525,7 +522,7 @@ vnc_connect(char *server, char *port, int share)
         return -err;
     }
 
-    DPRINTF("%s: Share desktop flag sent (%d)\n", PHPFUNC, buf[0]);
+    DPRINTF("%s: Share desktop flag sent (%d)\n", VNCFUNC, buf[0]);
 
     return sfd;
 }
@@ -545,16 +542,16 @@ vnc_read_server_init(int sfd)
     tServerFBParams params = { 0 };
     int len = 0, namelen = 0;
 
-    DPRINTF("%s: Server init - reading framebuffer parameters\n", PHPFUNC);
+    DPRINTF("%s: Server init - reading framebuffer parameters\n", VNCFUNC);
     if (read(sfd, tmpbuf, 24) < 0) {
         int err = errno;
-        DPRINTF("%s: Read function failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: Read function failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         goto cleanup;
     }
 
     namelen = (int)CALC_UINT32(tmpbuf[20], tmpbuf[21], tmpbuf[22], tmpbuf[23]);
-    DPRINTF("%s: Name length is %d\n", PHPFUNC, namelen);
+    DPRINTF("%s: Name length is %d\n", VNCFUNC, namelen);
 
     buf = (unsigned char *)malloc(namelen + 25);
     memset(buf, 0, namelen + 25);
@@ -562,15 +559,14 @@ vnc_read_server_init(int sfd)
 
     if ((len = read(sfd, buf + 24, namelen)) < 0) {
         int err = errno;
-        DPRINTF("%s: Read function failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: Read function failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         goto cleanup;
     }
 
     params = vnc_parse_fb_params(buf, len + 24);
  cleanup:
-    free(buf);
-    buf = NULL;
+    VIR_FREE(buf);
     return params;
 }
 
@@ -590,16 +586,16 @@ int vnc_get_dimensions(char *server, char *port, int *width, int *height)
     tServerFBParams params;
 
     if (!width && !height) {
-        DPRINTF("%s: Neither width or height output value not defined\n", PHPFUNC);
+        DPRINTF("%s: Neither width or height output value not defined\n", VNCFUNC);
         return -EINVAL;
     }
 
-    DPRINTF("%s: server is %s, port is %s\n", PHPFUNC, server, port);
+    DPRINTF("%s: server is %s, port is %s\n", VNCFUNC, server, port);
 
     sfd = vnc_connect(server, port, 1);
     if (sfd < 0) {
         int err = errno;
-        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
@@ -609,13 +605,13 @@ int vnc_get_dimensions(char *server, char *port, int *width, int *height)
     if (width) {
         *width = params.width;
 
-        DPRINTF("%s: Output parameter of width set to %d\n", PHPFUNC, *width);
+        DPRINTF("%s: Output parameter of width set to %d\n", VNCFUNC, *width);
     }
 
     if (height) {
         *height = params.height;
 
-        DPRINTF("%s: Output parameter of height set to %d\n", PHPFUNC, *height);
+        DPRINTF("%s: Output parameter of height set to %d\n", VNCFUNC, *height);
     }
 
     while (socket_has_data(sfd, 500000, 0) == 1)
@@ -623,7 +619,7 @@ int vnc_get_dimensions(char *server, char *port, int *width, int *height)
 
     shutdown(sfd, SHUT_RDWR);
     close(sfd);
-    DPRINTF("%s: Closed descriptor #%d\n", PHPFUNC, sfd);
+    DPRINTF("%s: Closed descriptor #%d\n", VNCFUNC, sfd);
     return 0;
 }
 
@@ -712,7 +708,7 @@ vnc_raw_to_bmp(char *infile, char *outfile, int width, int height)
         }
     }
 
-    free(pixels);
+    VIR_FREE(pixels);
     close(fd2);
     close(fd);
     return 0;
@@ -743,7 +739,7 @@ int vnc_get_bitmap(char *server, char *port, char *fn)
     sfd = vnc_connect(server, port, 1);
     if (sfd < 0) {
         int err = errno;
-        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
@@ -751,12 +747,12 @@ int vnc_get_bitmap(char *server, char *port, char *fn)
     params = vnc_read_server_init(sfd);
 
     pattern_size = params.width * params.height * (params.bpp / 8);
-    DPRINTF("%s: %ld\n", PHPFUNC, pattern_size);
+    DPRINTF("%s: %ld\n", VNCFUNC, pattern_size);
 
     vnc_set_pixel_format(sfd, params);
     vnc_set_encoding(sfd);
 
-    DPRINTF("%s: Requesting framebuffer update\n", PHPFUNC);
+    DPRINTF("%s: Requesting framebuffer update\n", VNCFUNC);
     vnc_send_framebuffer_update_request(sfd, 1, params);
 
     while (socket_has_data(sfd, 50000, 0) == 0) {
@@ -769,7 +765,7 @@ int vnc_get_bitmap(char *server, char *port, char *fn)
 
     vnc_raw_to_bmp(file, fn, params.width, params.height);
     unlink(file);
-    DPRINTF("%s: Closed descriptor #%d\n", PHPFUNC, sfd);
+    DPRINTF("%s: Closed descriptor #%d\n", VNCFUNC, sfd);
     return 0;
 }
 
@@ -788,12 +784,12 @@ int vnc_send_keys(char *server, char *port, char *keys)
     int i, skip_next;
     tServerFBParams params;
 
-    DPRINTF("%s: server is %s, port is %s, keys are '%s'\n", PHPFUNC, server, port, keys);
+    DPRINTF("%s: server is %s, port is %s, keys are '%s'\n", VNCFUNC, server, port, keys);
 
     sfd = vnc_connect(server, port, 1);
     if (sfd < 0) {
         int err = errno;
-        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
@@ -801,9 +797,9 @@ int vnc_send_keys(char *server, char *port, char *keys)
     params = vnc_read_server_init(sfd);
 
     skip_next = 0;
-    DPRINTF("%s: About to process key sequence '%s' (%d keys)\n", PHPFUNC, keys, (int)strlen(keys));
+    DPRINTF("%s: About to process key sequence '%s' (%d keys)\n", VNCFUNC, keys, (int)strlen(keys));
     for (i = 0; i < strlen(keys); i++) {
-        DPRINTF("%s: Processing key %d: %d [0x%02x]\n", PHPFUNC, i, keys[i], keys[i]);
+        DPRINTF("%s: Processing key %d: %d [0x%02x]\n", VNCFUNC, i, keys[i], keys[i]);
         if (skip_next) {
             skip_next = 0;
             continue;
@@ -818,25 +814,25 @@ int vnc_send_keys(char *server, char *port, char *keys)
             skip_next = 1;
         }
 
-        DPRINTF("%s: Sending key press emulation for key %d\n", PHPFUNC, keys[i]);
+        DPRINTF("%s: Sending key press emulation for key %d\n", VNCFUNC, keys[i]);
         vnc_send_key(sfd, keys[i], skip_next, 0);
-        DPRINTF("%s: Requesting framebuffer update\n", PHPFUNC);
+        DPRINTF("%s: Requesting framebuffer update\n", VNCFUNC);
         vnc_send_framebuffer_update_request(sfd, 1, params);
-        DPRINTF("%s: Sending key release emulation for key %d\n", PHPFUNC, keys[i]);
+        DPRINTF("%s: Sending key release emulation for key %d\n", VNCFUNC, keys[i]);
         vnc_send_key(sfd, keys[i], skip_next, 1);
 
         /* Sleep for 50 ms, required to make VNC server accept the keystroke emulation */
         usleep(50000);
     }
 
-    DPRINTF("%s: All %d keys sent\n", PHPFUNC, (int)strlen(keys));
+    DPRINTF("%s: All %d keys sent\n", VNCFUNC, (int)strlen(keys));
 
     while (socket_has_data(sfd, 500000, 0) == 1)
         socket_read(sfd, -1);
 
     shutdown(sfd, SHUT_RDWR);
     close(sfd);
-    DPRINTF("%s: Closed descriptor #%d\n", PHPFUNC, sfd);
+    DPRINTF("%s: Closed descriptor #%d\n", VNCFUNC, sfd);
     return 0;
 }
 
@@ -857,13 +853,13 @@ int vnc_send_pointer_event(char *server, char *port, int pos_x, int pos_y, int c
     int sfd;
     tServerFBParams params;
 
-    DPRINTF("%s: Server is %s, port is %s, x is %d, y is %d, clicked is %d, release is %d\n", PHPFUNC,
+    DPRINTF("%s: Server is %s, port is %s, x is %d, y is %d, clicked is %d, release is %d\n", VNCFUNC,
             server, port, pos_x, pos_y, clicked, release);
 
     sfd = vnc_connect(server, port, 0);
     if (sfd < 0) {
         int err = errno;
-        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
@@ -873,7 +869,7 @@ int vnc_send_pointer_event(char *server, char *port, int pos_x, int pos_y, int c
     if (((pos_x > params.width) || (pos_y < 0))
         || ((pos_y > params.height) || (pos_y < 0))) {
         DPRINTF("%s: Required positions out of range (width = %d, height = %d, x = %d, y = %d) for '%s'\n",
-                PHPFUNC, params.width, params.height, pos_x, pos_y, params.desktopName);
+                VNCFUNC, params.width, params.height, pos_x, pos_y, params.desktopName);
         return -EINVAL;
     }
 
@@ -904,7 +900,7 @@ int vnc_send_pointer_event(char *server, char *port, int pos_x, int pos_y, int c
     shutdown(sfd, SHUT_RDWR);
     close(sfd);
 
-    DPRINTF("%s: Closed descriptor #%d\n", PHPFUNC, sfd);
+    DPRINTF("%s: Closed descriptor #%d\n", VNCFUNC, sfd);
 
     return 0;
 }
@@ -923,29 +919,29 @@ int vnc_refresh_screen(char *server, char *port, int scancode)
     int sfd;
     tServerFBParams params;
 
-    DPRINTF("%s: Server is %s, port is %s, scancode is %d\n", PHPFUNC, server, port, scancode);
+    DPRINTF("%s: Server is %s, port is %s, scancode is %d\n", VNCFUNC, server, port, scancode);
 
-    DPRINTF("%s: server is %s, port is %s\n", PHPFUNC, server, port);
+    DPRINTF("%s: server is %s, port is %s\n", VNCFUNC, server, port);
 
     sfd = vnc_connect(server, port, 1);
     if (sfd < 0) {
         int err = errno;
-        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", PHPFUNC, err, strerror(err));
+        DPRINTF("%s: VNC Connection failed with error code %d (%s)\n", VNCFUNC, err, strerror(err));
         close(sfd);
         return -err;
     }
 
     params = vnc_read_server_init(sfd);
 
-    DPRINTF("%s: Sending key press emulation for key %d\n", PHPFUNC, scancode);
+    DPRINTF("%s: Sending key press emulation for key %d\n", VNCFUNC, scancode);
     if (scancode > -1)
         vnc_send_key(sfd, scancode, 1, 0);
 
-    DPRINTF("%s: Requesting framebuffer update\n", PHPFUNC);
+    DPRINTF("%s: Requesting framebuffer update\n", VNCFUNC);
     vnc_send_framebuffer_update_request(sfd, 1, params);
 
     shutdown(sfd, SHUT_RDWR);
     close(sfd);
-    DPRINTF("%s: Closed descriptor #%d\n", PHPFUNC, sfd);
+    DPRINTF("%s: Closed descriptor #%d\n", VNCFUNC, sfd);
     return 0;
 }
